==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AShortBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.AShortBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5be6421164f624e0 soot_jimple_parser_node_AShortBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_AShortBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_AShortBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TShort$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$refs	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$_init$23f43e9289eb1226(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TShort$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *);
extern struct _jc_soot_jimple_parser_node_TShort$object *_jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$getShort$7f2ee6a84e03e13a(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$setShort$422df9f3be44e5aa(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TShort$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$getShort$7f2ee6a84e03e13a;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$setShort$422df9f3be44e5aa;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *);
	struct _jc_soot_jimple_parser_node_TShort$object	*(*getShort$7f2ee6a84e03e13a)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setShort$422df9f3be44e5aa)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TShort$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vmethods	soot_jimple_parser_node_AShortBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TShort$object	*__5fshort__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_refs	soot_jimple_parser_node_AShortBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_AShortBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype _jc_soot_jimple_parser_node_AShortBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AShortBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AShortBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AShortBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AShortBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.AShortBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5be6421164f624e0 soot_jimple_parser_node_AShortBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_AShortBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_AShortBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TShort$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$refs	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$_init$23f43e9289eb1226(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TShort$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TShort$object *_jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$getShort$7f2ee6a84e03e13a(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$setShort$422df9f3be44e5aa(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TShort$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AShortBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$getShort$7f2ee6a84e03e13a;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$setShort$422df9f3be44e5aa;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TShort$object	*(*getShort$7f2ee6a84e03e13a)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setShort$422df9f3be44e5aa)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TShort$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vmethods	soot_jimple_parser_node_AShortBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TShort$object	*__5fshort__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_refs	soot_jimple_parser_node_AShortBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_AShortBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_AShortBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AShortBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AShortBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AShortBaseTypeNoName$vtype _jc_soot_jimple_parser_node_AShortBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AShortBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AShortBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AShortBaseTypeNoName_H_ */
